@@ -94,7 +94,7 @@ class Matcher(Preprocessor):
     Read in the already created pickle files for each dictionary in the
     preprocessing step.
     '''
-    name = self.proteome.split('.')[0]
+    name = self.proteome.replace('.fa', '').replace('.fasta', '')
     with open(name + '_' + str(self.split) + 'mers' + '.pickle', 'rb') as f:
       kmer_dict = pickle.load(f)
     with open(name + '_names.pickle', 'rb') as f:
@@ -386,7 +386,7 @@ class Matcher(Preprocessor):
           all_matches.append((
             peptide,
             match[0],
-            names_dict[(match[2] - (match[2] % 100000)) // 100000],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][0],
             match[1],
             [i+1 for i in range(len(peptide)) if peptide[i] != match[0][i]],
             match[2] % 100000,
